Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(17)

Unified Diff: Source/modules/webaudio/AudioBufferSourceNode.h

Issue 349213007: WebAudio: Remove AudioNode::RefType. (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/modules/webaudio/AudioBufferSourceNode.h
diff --git a/Source/modules/webaudio/AudioBufferSourceNode.h b/Source/modules/webaudio/AudioBufferSourceNode.h
index cb24a38c09abeaf47b8781f3a3c48fec9ed56821..4e91132db2412a96e75f09ada1647c62b37505d9 100644
--- a/Source/modules/webaudio/AudioBufferSourceNode.h
+++ b/Source/modules/webaudio/AudioBufferSourceNode.h
@@ -130,9 +130,12 @@ private:
// It incorporates the base pitch rate, any sample-rate conversion factor from the buffer, and any doppler shift from an associated panner node.
double totalPitchRate();
- // We optionally keep track of a panner node which has a doppler shift that is incorporated into
- // the pitch rate. We manually manage ref-counting because we want to use RefTypeConnection.
- PannerNode* m_pannerNode;
+ // We optionally keep track of a panner node which has a doppler shift that
+ // is incorporated into the pitch rate.
+ // This RefPtr makes the node graph. We need to call AudioNode::
Raymond Toy 2014/07/09 22:10:33 What do you mean by "makes the node graph"?
tkent 2014/07/10 08:07:42 It means a connection type reference. I'll improv
+ // wasConnected() after ref(), and call AudioNode::willBeDisconnected()
+ // before deref().
Raymond Toy 2014/07/09 22:10:33 Does this comment about wasConnected() and willBeD
tkent 2014/07/10 08:07:41 Right.
+ RefPtr<PannerNode> m_pannerNode;
// This synchronizes process() with setBuffer() which can cause dynamic channel count changes.
mutable Mutex m_processLock;
« no previous file with comments | « no previous file | Source/modules/webaudio/AudioBufferSourceNode.cpp » ('j') | Source/modules/webaudio/AudioContext.cpp » ('J')

Powered by Google App Engine
This is Rietveld 408576698